@@ -1,11 +1,12 @@
 # ABSTRACT: Module that provides simple named locks
 package App::Highlander;
-$App::Highlander::VERSION = '0.002';
+$App::Highlander::VERSION = '0.003';
 use strict;
 use warnings;
 
 use English qw(-no_match_vars);
 use Fcntl qw(:flock);
+use File::Temp qw/tempdir/; 
 use Path::Tiny;
 
 our $LOCKDIR;
@@ -13,9 +14,9 @@ sub import {
    my ($self, %args) = @_;
 
    _create_if_not_exists(
-      $LOCKDIR = $args{LOCKDIR} // '/var/highlander/'
+      $LOCKDIR = $args{LOCKDIR} // tempdir( CLEANUP => 1 )
    );
-
+   print "LOCKDIR='$LOCKDIR'\n";
    return;
 }
 
@@ -90,7 +91,7 @@ App::Highlander - Module that provides simple named locks
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -123,9 +124,9 @@ or
 
 =head1 DESCRIPTION
 
-Simple module that provides a named locking mechanism based on flock. Application code requests a lock, then executes, then releases the lock. Lockfiles are stored in /var/highlander by default. You can optionally specify a different LOCK directory when using App::Highlander by specifying the LOCKDIR option. /var/highlander needs to exist and the user running the Highlander'd script needs to have write and read permisissions on files in /var/highlander.
+Simple module that provides a named locking mechanism based on flock. Application code requests a lock, then executes, then releases the lock. Lockfiles are stored in a temporary directory created by File::Temp::tempdir( CLEANUP => 1 ) by default. You can optionally use a different LOCKDIR directory when using App::Highlander by specifying the LOCKDIR option. Keep in mind that any directory you specify needs to exist and the user running the Highlander'd script needs to have write and read permisissions on files in that directory.
 
-App::Highlander does *not* currently (and may never) handle errors, this means that if you application dies under Highlander then it will not have released the lock. Application code will need to capture the error with eval or a sugary module like Try::Tiny then explicitly release the lock.
+App::Highlander does *not* currently (and may never) handle errors, this means that if your application dies under Highlander then it will not have released the lock. Application code will need to capture the error with eval or a sugary module like Try::Tiny then explicitly release the lock.
 
 =head1 NAME
 
@@ -137,7 +138,7 @@ App::Highlander
 
 =item C<get_lock>
 
-Attempts to get a lock on the supplied lock string. If no lock string is supplied then $PROGRAM_NAME will be used. Locks are written to /var/highlander/.
+Attempts to get a lock on the supplied lock string. If no lock string is supplied then $PROGRAM_NAME will be used. Locks are written to a temporary directory or LOCKDIR if one was specified
 Returns the name of the lock file that was created.
 
 =item C<release_lock>
